PCB Environment: IndexRange Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
IndexRange Struct Reference

## Public Member Functions
| IndexRange (uint z0, uint z1, uint y0, uint y1, uint x0, uint x1)
uint | countX () const
uint | countY () const
uint | countXY () const
uint | countZ () const
uint | count () const

## Data Fields
uint | Z0
uint | Z1
uint | Y0
uint | Y1
uint | X0
uint | X1

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Rasterizer.hpp